==> haskell-monad-journal-0.8.1-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-esUL7kPPPM2FdfeHHukmg
key:                  monad-journal-0.8.1-esUL7kPPPM2FdfeHHukmg
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  08af2afb109d40d7884f6de3557be2ea
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-journal-0.8.1
hs-libraries:         HSmonad-journal-0.8.1-esUL7kPPPM2FdfeHHukmg
depends:
    base-4.14.1.0 monad-control-1.0.2.3-27B6mpTRmEH9CsV546tlkg
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-4UUGwAxnko8BoB8voh1uxd

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-FfYpoCikVFUBOD2KySWfC4
key:                  monad-journal-0.8.1-FfYpoCikVFUBOD2KySWfC4
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  0490696b18af1501f7c2b2ab11ba171b
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-journal-0.8.1
hs-libraries:         HSmonad-journal-0.8.1-FfYpoCikVFUBOD2KySWfC4
depends:
    base-4.14.1.0 monad-control-1.0.2.3-2OeC3k7tZxRD9Asvn7oh1h
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-7CaHVRpkADT25BLxr1p5Ie

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
